@@ -71,39 +71,7 @@ autosummary.Autosummary = NewAuto
 
 import sphinx_bootstrap_theme
 
-# We currently rely on the latest version of numpydoc available on GitHub:
-#   git+git://github.com/numpy/numpydoc.git
-#
-# There isn't a way to specify this in setup.py as a dependency since this
-# feature is being removed from pip. We also can't check the version of
-# numpydoc installed because there isn't a numpydoc.__version__ defined.
-try:
-    import numpydoc
-except ImportError:
-    raise RuntimeError(
-        "numpydoc v0.6 or later required. Install it with:\n"
-        "  pip install git+git://github.com/numpy/numpydoc.git@1a848331c2cf53"
-        "d4fe356f4607799524bcc577ed")
-
-@property
-def _extras(self):
-    # This will be accessed in a for-loop, so memoize to prevent quadratic
-    # behavior.
-    if not hasattr(self, '__memoized_extras'):
-        # We want every dunder that has a function type (not class slot),
-        # meaning we created the dunder, not Python.
-        # We don't ever care about __init__ and the user will see plenty of
-        # __repr__ calls, so why waste space.
-        self.__memoized_extras = [
-            a for a, v in inspect.getmembers(self._cls)
-            if type(v) == types.FunctionType and a.startswith('__')
-            and a not in ['__init__', '__repr__']
-        ]
-    return self.__memoized_extras
-
 # The extra_public_methods depends on what class we are looking at.
-numpydoc.docscrape.ClassDoc.extra_public_methods = _extras
-
 
 import skbio
 from skbio.util._decorator import classproperty
@@ -119,7 +87,7 @@ from skbio.util._decorator import classproperty
 # If your documentation needs a minimal Sphinx version, state it here.
 # Using `sphinx_version` doesn't work, likely because Sphinx is expecting a
 # version string of the form X.Y, not X.Y.Z.
-needs_sphinx = '1.2'
+needs_sphinx = '1.6'
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
@@ -127,7 +95,8 @@ needs_sphinx = '1.2'
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.mathjax',
-    'numpydoc',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.linkcode',
     'sphinx.ext.coverage',
     'sphinx.ext.doctest',
     'sphinx.ext.autosummary',
@@ -401,14 +370,6 @@ texinfo_documents = [
 # -- Options for autosummary ----------------------------------------------
 autosummary_generate = glob.glob('*.rst')
 
-# -- Options for numpydoc -------------------------------------------------
-# Generate plots for example sections
-numpydoc_use_plots = True
-# If we don't turn numpydoc's toctree generation off, Sphinx will warn about
-# the toctree referencing missing document(s). This appears to be related to
-# generating docs for classes with a __call__ method.
-numpydoc_class_members_toctree = False
-
 #------------------------------------------------------------------------------
 # Plot
 #------------------------------------------------------------------------------
@@ -466,16 +427,6 @@ intersphinx_mapping = {
 import inspect
 from os.path import relpath, dirname
 
-for name in ['sphinx.ext.linkcode', 'linkcode', 'numpydoc.linkcode']:
-    try:
-        __import__(name)
-        extensions.append(name)
-        break
-    except ImportError:
-        pass
-else:
-    print "NOTE: linkcode extension not found -- no links to source generated"
-
 def linkcode_resolve(domain, info):
     """
     Determine the URL corresponding to Python object
@@ -535,24 +486,17 @@ def linkcode_resolve(domain, info):
 # Link-checking on Travis sometimes times out.
 linkcheck_timeout = 30
 
-# This is so that our docs build.
+# You might see the following exception when building the documentation:
+# TypeError: 'abstractproperty' object is not iterable
 def _closure():
     def __get__(self, cls, owner):
         return self
 
     classproperty.__get__ = __get__
-
 _closure()
 
-def autodoc_skip_member(app, what, name, obj, skip, options):
-    if what == "method":
-        if isinstance(obj, classproperty):
-            return True
-    return skip
-
 # Add the 'copybutton' javascript, to hide/show the prompt in code
 # examples, originally taken from scikit-learn's doc/conf.py
 def setup(app):
     app.add_javascript('copybutton.js')
     app.add_stylesheet('style.css')
-    app.connect('autodoc-skip-member', autodoc_skip_member)
