@@ -33,36 +33,39 @@ class OrdinationTestData(TestCase):
         # raised when reading the file, and whether the file should be matched
         # by the sniffer (True) or not (False).
         self.invalid_fps = map(lambda e: (get_data_path(e[0]), e[1], e[2]), [
-            ('empty', 'end of file.*Eigvals header', False),
-            ('whitespace_only', 'Eigvals header not found', False),
-            ('ordination_error1', 'Eigvals header not found', False),
+            ('empty', r'end of file.*Eigvals header', False),
+            ('whitespace_only', r'Eigvals header not found', False),
+            ('ordination_error1', r'Eigvals header not found', False),
             ('ordination_error2',
-             'Proportion explained header not found', False),
-            ('ordination_error3', 'Species header not found', True),
-            ('ordination_error4', 'Site header not found', True),
-            ('ordination_error5', 'Biplot header not found', True),
-            ('ordination_error6', 'Site constraints header not found', True),
-            ('ordination_error7', 'empty line', False),
-            ('ordination_error8', '9.*Proportion explained.*8', True),
-            ('ordination_error9', '2 values.*1 in row 1', True),
-            ('ordination_error10', '2 values.*1 in row 1', True),
-            ('ordination_error11', 'Site constraints ids and site ids', True),
-            ('ordination_error12', '9.*Eigvals.*8', True),
-            ('ordination_error13', '9.*Proportion explained.*8', True),
-            ('ordination_error14', 'Site is 0: 9 x 0', True),
-            ('ordination_error15', '9 values.*8 in row 1', True),
-            ('ordination_error16', 'Biplot is 0: 3 x 0', True),
-            ('ordination_error17', '3 values.*2 in row 1', True),
+             r'Proportion explained header not found', False),
+            ('ordination_error3', r'Species header not found', True),
+            ('ordination_error4', r'Site header not found', True),
+            ('ordination_error5', r'Biplot header not found', True),
+            ('ordination_error6', r'Site constraints header not found', True),
+            ('ordination_error7', r'empty line', False),
+            ('ordination_error8', r'9.*Proportion explained.*8', True),
+            ('ordination_error9', r'2 values.*1 in row 1', True),
+            ('ordination_error10', r'2 values.*1 in row 1', True),
+            ('ordination_error11', r'Site constraints ids and site ids', True),
+            ('ordination_error12', r'9.*Eigvals.*8', True),
+            ('ordination_error13', r'9.*Proportion explained.*8', True),
+            ('ordination_error14', r'Site is 0: 9 x 0', True),
+            ('ordination_error15', r'9 values.*8 in row 1', True),
+            ('ordination_error16', r'Biplot is 0: 3 x 0', True),
+            ('ordination_error17', r'3 values.*2 in row 1', True),
             ('ordination_error18',
-             'proportion explained.*eigvals: 8 != 9', True),
+             r'proportion explained.*eigvals: 8 != 9', True),
             ('ordination_error19',
-             'coordinates.*species.*eigvals: 1 != 2', True),
-            ('ordination_error20', 'coordinates.*site.*eigvals: 1 != 2', True),
-            ('ordination_error21', 'one eigval', False),
-            ('ordination_error22', 'end of file.*blank line', False),
-            ('ordination_error23', 'end of file.*Proportion explained section',
+             r'coordinates.*species.*eigvals: 1 != 2', True),
+            ('ordination_error20',
+             r'coordinates.*site.*eigvals: 1 != 2', True),
+            ('ordination_error21', r'one eigval', False),
+            ('ordination_error22', r'end of file.*blank line', False),
+            ('ordination_error23',
+             r'end of file.*Proportion explained section',
              True),
-            ('ordination_error24', 'end of file.*row 2.*Species section', True)
+            ('ordination_error24',
+             r'end of file.*row 2.*Species section', True)
         ])
 
 
