@@ -101,19 +101,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
     This class is intended to be inherited from to create grammared sequences
     with custom alphabets.
 
-    Attributes
-    ----------
-    values
-    metadata
-    interval_metadata
-    positional_metadata
-    alphabet
-    gap_chars
-    default_gap_char
-    definite_chars
-    degenerate_chars
-    degenerate_map
-
     Raises
     ------
     ValueError
@@ -193,8 +180,9 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # TODO These masks could be defined (as literals) on each concrete
         # object. For now, memoize!
         if cls.__validation_mask is None:
+            as_bytes = ''.join(cls.alphabet).encode('ascii')
             cls.__validation_mask = np.invert(np.bincount(
-                np.fromstring(''.join(cls.alphabet), dtype=np.uint8),
+                np.frombuffer(as_bytes, dtype=np.uint8),
                 minlength=cls._number_of_extended_ascii_codes).astype(bool))
         return cls.__validation_mask
 
@@ -281,7 +269,7 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         return set(cls.degenerate_map)
 
     @classproperty
-    @deprecated(as_of='0.5.0', until='0.5.3',
+    @deprecated(as_of='0.5.0', until='0.6.0',
                 reason='Renamed to definite_chars')
     def nondegenerate_chars(cls):
         """Return non-degenerate characters.
@@ -492,7 +480,7 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         """
         return np.in1d(self._bytes, self._definite_char_codes)
 
-    @deprecated(as_of='0.5.0', until='0.5.3',
+    @deprecated(as_of='0.5.0', until='0.6.0',
                 reason='Renamed to definites')
     def nondegenerates(self):
         """Find positions containing non-degenerate characters in the sequence.
@@ -548,7 +536,7 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # TODO: cache results
         return bool(self.definites().any())
 
-    @deprecated(as_of='0.5.0', until='0.5.3',
+    @deprecated(as_of='0.5.0', until='0.6.0',
                 reason='Renamed to has_definites')
     def has_nondegenerates(self):
         """Determine if sequence contains one or more non-degenerate characters
