@@ -42,7 +42,7 @@ class Sequence(MetadataMixin, PositionalMetadataMixin, IntervalMetadataMixin,
 
     Parameters
     ----------
-    sequence : str, Sequence, or 1D np.ndarray (np.uint8 or '\|S1')
+    sequence : str, Sequence, or 1D np.ndarray (np.uint8 or '\\|S1')
         Characters representing the sequence itself.
     metadata : dict, optional
         Arbitrary metadata which applies to the entire sequence. A shallow copy
@@ -64,14 +64,6 @@ class Sequence(MetadataMixin, PositionalMetadataMixin, IntervalMetadataMixin,
         and a ``True`` value will be stored in a boolean array in the
         positional metadata under the key.
 
-    Attributes
-    ----------
-    values
-    metadata
-    positional_metadata
-    interval_metadata
-    observed_chars
-
     See Also
     --------
     DNA
@@ -106,9 +98,9 @@ class Sequence(MetadataMixin, PositionalMetadataMixin, IntervalMetadataMixin,
 
     Create a sequence with metadata and positional metadata:
 
-    >>> metadata = {'id':'seq-id', 'desc':'seq desc', 'authors': ['Alice']}
-    >>> positional_metadata = {'quality': [3, 3, 4, 10],
-    ...                        'exons': [True, True, False, True]}
+    >>> metadata = {'authors': ['Alice'], 'desc':'seq desc', 'id':'seq-id'}
+    >>> positional_metadata = {'exons': [True, True, False, True],
+    ...                        'quality': [3, 3, 4, 10]}
     >>> interval_metadata = IntervalMetadata(4)
     >>> interval = interval_metadata.add([(1, 3)], metadata={'gene': 'sagA'})
     >>> seq = Sequence('ACGT', metadata=metadata,
@@ -249,7 +241,7 @@ fuzzy=[(False, False)], metadata={'gene': 'sagA'})
     ``pd.DataFrame``:
 
     >>> positional_metadata = pd.DataFrame(
-    ...     {'quality': [3, 3, 4, 10], 'list': [[], [], [], []]})
+    ...     {'list': [[], [], [], []], 'quality': [3, 3, 4, 10]})
     >>> seq = Sequence('ACGT', positional_metadata=positional_metadata)
     >>> seq
     Sequence
@@ -359,7 +351,6 @@ fuzzy=[(False, False)], metadata={'gene': 'foo'})
     >>> print(intervals[0])  # doctest: +ELLIPSIS
     Interval(interval_metadata=<...>, bounds=[(0, 2)], \
 fuzzy=[(True, False)], metadata={'gene': 'foo'})
-
     """
     _number_of_extended_ascii_codes = 256
     # ASCII is built such that the difference between uppercase and lowercase
@@ -372,7 +363,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
     @property
     @stable(as_of="0.4.0")
     def values(self):
-        """Array containing underlying sequence characters.
+        r"""Array containing underlying sequence characters.
 
         Notes
         -----
@@ -391,7 +382,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @property
     def __array_interface__(self):
-        """Array interface for compatibility with numpy.
+        r"""Array interface for compatibility with numpy.
 
         This property allows a ``Sequence`` object to share its underlying data
         buffer (``Sequence.values``) with numpy. See [1]_ for more details.
@@ -415,7 +406,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
     @property
     @experimental(as_of="0.4.1")
     def observed_chars(self):
-        """Set of observed characters in the sequence.
+        r"""Set of observed characters in the sequence.
 
         Notes
         -----
@@ -438,7 +429,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
     @classonlymethod
     @experimental(as_of="0.4.1")
     def concat(cls, sequences, how='strict'):
-        """Concatenate an iterable of ``Sequence`` objects.
+        r"""Concatenate an iterable of ``Sequence`` objects.
 
         Parameters
         ----------
@@ -569,7 +560,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
             if not seq.has_positional_metadata():
                 del seq.positional_metadata
 
-        pm = pd.concat(pm_data, join=how, ignore_index=True)
+        pm = pd.concat(pm_data, join=how, ignore_index=True, sort=True)
         bytes_ = np.concatenate(seq_data)
 
         im = IntervalMetadata.concat(i.interval_metadata for i in seqs)
@@ -628,11 +619,11 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
             # Encode as ascii to raise UnicodeEncodeError if necessary.
             if isinstance(sequence, str):
                 sequence = sequence.encode("ascii")
-            s = np.fromstring(sequence, dtype=np.uint8)
+            s = np.frombuffer(sequence, dtype=np.uint8)
 
             # There are two possibilities (to our knowledge) at this point:
             # Either the sequence we were given was something string-like,
-            # (else it would not have made it past fromstring), or it was a
+            # (else it would not have made it past frombuffer), or it was a
             # numpy scalar, and so our length must be 1.
             if isinstance(sequence, np.generic) and len(s) != 1:
                 raise TypeError("Can cannot create a sequence with %r" %
@@ -663,7 +654,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
                             "string, but got %s" % type(lowercase))
 
     def _set_bytes_contiguous(self, sequence):
-        """Munge the sequence data into a numpy array of dtype uint8."""
+        r"""Munge the sequence data into a numpy array of dtype uint8."""
         if not sequence.flags['C_CONTIGUOUS']:
             # numpy doesn't support views of non-contiguous arrays. Since we're
             # making heavy use of views internally, and users may also supply
@@ -687,7 +678,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __contains__(self, subsequence):
-        """Determine if a subsequence is contained in this sequence.
+        r"""Determine if a subsequence is contained in this sequence.
 
         Parameters
         ----------
@@ -713,13 +704,12 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
         True
         >>> 'CCC' in s
         False
-
         """
         return self._munge_to_bytestring(subsequence, "in") in self._string
 
     @stable(as_of="0.4.0")
     def __eq__(self, other):
-        """Determine if this sequence is equal to another.
+        r"""Determine if this sequence is equal to another.
 
         Sequences are equal if they are *exactly* the same type and their
         sequence characters, metadata, and positional metadata are the same.
@@ -794,7 +784,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __ne__(self, other):
-        """Determine if this sequence is not equal to another.
+        r"""Determine if this sequence is not equal to another.
 
         Sequences are not equal if they are not *exactly* the same type, or
         their sequence characters, metadata, or positional metadata differ.
@@ -828,7 +818,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __getitem__(self, indexable):
-        """Slice this sequence.
+        r"""Slice this sequence.
 
         Notes
         -----
@@ -922,7 +912,8 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
                     if self.has_positional_metadata():
                         pos_md_slices = list(_slices_from_iter(
                                              self.positional_metadata, index))
-                        positional_metadata = pd.concat(pos_md_slices)
+                        positional_metadata = pd.concat(pos_md_slices,
+                                                        sort=True)
 
                     metadata = None
                     if self.has_metadata():
@@ -973,7 +964,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __len__(self):
-        """Return the number of characters in this sequence.
+        r"""Return the number of characters in this sequence.
 
         Returns
         -------
@@ -992,7 +983,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __bool__(self):
-        """Returns truth value (truthiness) of sequence.
+        r"""Returns truth value (truthiness) of sequence.
 
         Returns
         -------
@@ -1012,7 +1003,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __iter__(self):
-        """Iterate over positions in this sequence.
+        r"""Iterate over positions in this sequence.
 
         Yields
         ------
@@ -1037,7 +1028,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __reversed__(self):
-        """Iterate over positions in this sequence in reverse order.
+        r"""Iterate over positions in this sequence in reverse order.
 
         Yields
         ------
@@ -1061,7 +1052,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __str__(self):
-        """Return sequence characters as a string.
+        r"""Return sequence characters as a string.
 
         Returns
         -------
@@ -1152,8 +1143,8 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
         ...     'published': True
         ... }
         >>> positional_metadata = {
-        ...     'quality': [3, 10, 11, 10],
-        ...     'exons': [True, True, False, True]
+        ...     'exons': [True, True, False, True],
+        ...     'quality': [3, 10, 11, 10]
         ... }
         >>> seq = Sequence('ACGT', metadata=metadata,
         ...          positional_metadata=positional_metadata)
@@ -1186,7 +1177,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
             chunk_size=10).build()
 
     def _repr_stats(self):
-        """Define statistics to display in the sequence's repr.
+        r"""Define statistics to display in the sequence's repr.
 
         Subclasses can override this method to provide type-specific
         statistics.
@@ -1207,7 +1198,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __copy__(self):
-        """Return a shallow copy of this sequence.
+        r"""Return a shallow copy of this sequence.
 
         See Also
         --------
@@ -1222,7 +1213,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def __deepcopy__(self, memo):
-        """Return a deep copy of this sequence.
+        r"""Return a deep copy of this sequence.
 
         See Also
         --------
@@ -1270,7 +1261,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of='0.4.0')
     def lowercase(self, lowercase):
-        """Return a case-sensitive string representation of the sequence.
+        r"""Return a case-sensitive string representation of the sequence.
 
         Parameters
         ----------
@@ -1318,7 +1309,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def count(self, subsequence, start=None, end=None):
-        """Count occurrences of a subsequence in this sequence.
+        r"""Count occurrences of a subsequence in this sequence.
 
         Parameters
         ----------
@@ -1364,7 +1355,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @experimental(as_of="0.5.0")
     def replace(self, where, character):
-        """Replace values in this sequence with a different character.
+        r"""Replace values in this sequence with a different character.
 
         Parameters
         ----------
@@ -1449,7 +1440,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def index(self, subsequence, start=None, end=None):
-        """Find position where subsequence first occurs in the sequence.
+        r"""Find position where subsequence first occurs in the sequence.
 
         Parameters
         ----------
@@ -1490,7 +1481,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @experimental(as_of="0.4.0")
     def distance(self, other, metric=None):
-        """Compute the distance to another sequence.
+        r"""Compute the distance to another sequence.
 
         Parameters
         ----------
@@ -1552,7 +1543,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def matches(self, other):
-        """Find positions that match with another sequence.
+        r"""Find positions that match with another sequence.
 
         Parameters
         ----------
@@ -1594,7 +1585,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def mismatches(self, other):
-        """Find positions that do not match with another sequence.
+        r"""Find positions that do not match with another sequence.
 
         Parameters
         ----------
@@ -1632,7 +1623,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def match_frequency(self, other, relative=False):
-        """Return count of positions that are the same between two sequences.
+        r"""Return count of positions that are the same between two sequences.
 
         Parameters
         ----------
@@ -1682,7 +1673,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def mismatch_frequency(self, other, relative=False):
-        """Return count of positions that differ between two sequences.
+        r"""Return count of positions that differ between two sequences.
 
         Parameters
         ----------
@@ -1732,7 +1723,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @experimental(as_of="0.4.1")
     def frequencies(self, chars=None, relative=False):
-        """Compute frequencies of characters in the sequence.
+        r"""Compute frequencies of characters in the sequence.
 
         Parameters
         ----------
@@ -1831,7 +1822,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
         return dict(zip(chars, obs_counts.tolist()))
 
     def _chars_to_indices(self, chars):
-        """Helper for Sequence.frequencies."""
+        r"""Helper for Sequence.frequencies."""
         if isinstance(chars, (str, bytes)):
             chars = set([chars])
         elif not isinstance(chars, set):
@@ -1862,7 +1853,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def iter_kmers(self, k, overlap=True):
-        """Generate kmers of length `k` from this sequence.
+        r"""Generate kmers of length `k` from this sequence.
 
         Parameters
         ----------
@@ -1933,7 +1924,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def kmer_frequencies(self, k, overlap=True, relative=False):
-        """Return counts of words of length `k` from this sequence.
+        r"""Return counts of words of length `k` from this sequence.
 
         Parameters
         ----------
@@ -1986,7 +1977,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def find_with_regex(self, regex, ignore=None):
-        """Generate slices for patterns matched by a regular expression.
+        r"""Generate slices for patterns matched by a regular expression.
 
         Parameters
         ----------
@@ -2035,7 +2026,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
 
     @stable(as_of="0.4.0")
     def iter_contiguous(self, included, min_length=1, invert=False):
-        """Yield contiguous subsequences based on `included`.
+        r"""Yield contiguous subsequences based on `included`.
 
         Parameters
         ----------
@@ -2106,7 +2097,7 @@ fuzzy=[(True, False)], metadata={'gene': 'foo'})
         return self.__class__(**kwargs)
 
     def _munge_to_index_array(self, sliceable):
-        """Return an index array from something isomorphic to a boolean vector.
+        r"""Return an index array from something isomorphic to a boolean vector.
 
         """
         if isinstance(sliceable, str):
