@@ -32,9 +32,9 @@ class TestGeneticCode(unittest.TestCase):
                          'Candidate Division SR1 and Gracilibacteria')
 
     def test_from_ncbi_invalid_input(self):
-        with self.assertRaisesRegex(ValueError, 'table_id.*7'):
+        with self.assertRaisesRegex(ValueError, r'table_id.*7'):
             GeneticCode.from_ncbi(7)
-        with self.assertRaisesRegex(ValueError, 'table_id.*42'):
+        with self.assertRaisesRegex(ValueError, r'table_id.*42'):
             GeneticCode.from_ncbi(42)
 
     def test_reading_frames(self):
@@ -72,27 +72,27 @@ class TestGeneticCode(unittest.TestCase):
 
     def test_init_invalid_input(self):
         # `amino_acids` invalid protein
-        with self.assertRaisesRegex(ValueError, 'Invalid character.*J'):
+        with self.assertRaisesRegex(ValueError, r'Invalid character.*J'):
             GeneticCode('J' * 64, '-' * 64)
 
         # wrong number of amino acids
-        with self.assertRaisesRegex(ValueError, 'amino_acids.*64.*42'):
+        with self.assertRaisesRegex(ValueError, r'amino_acids.*64.*42'):
             GeneticCode('M' * 42, '-' * 64)
 
         # `amino_acids` missing M
-        with self.assertRaisesRegex(ValueError, 'amino_acids.*M.*character'):
+        with self.assertRaisesRegex(ValueError, r'amino_acids.*M.*character'):
             GeneticCode('A' * 64, '-' * 64)
 
         # `starts` invalid protein
-        with self.assertRaisesRegex(ValueError, 'Invalid character.*J'):
+        with self.assertRaisesRegex(ValueError, r'Invalid character.*J'):
             GeneticCode('M' * 64, 'J' * 64)
 
         # wrong number of starts
-        with self.assertRaisesRegex(ValueError, 'starts.*64.*42'):
+        with self.assertRaisesRegex(ValueError, r'starts.*64.*42'):
             GeneticCode('M' * 64, '-' * 42)
 
         # invalid characters in `starts`
-        with self.assertRaisesRegex(ValueError, 'starts.*M and - characters'):
+        with self.assertRaisesRegex(ValueError, r'starts.*M and - characters'):
             GeneticCode('M' * 64, '-M' * 30 + '*AQR')
 
     def test_str(self):
@@ -249,7 +249,7 @@ class TestGeneticCode(unittest.TestCase):
                 self.assertEqual(obs, exp)
 
             with self.assertRaisesRegex(ValueError,
-                                        'reading_frame=1.*start=\'require\''):
+                                        r'reading_frame=1.*start=\'require\''):
                 self.sgc.translate(seq, start='require')
 
     def test_translate_start_with_start_codon(self):
@@ -293,7 +293,7 @@ class TestGeneticCode(unittest.TestCase):
             self.assertEqual(obs, exp)
 
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=1.*start=\'require\''):
+                                    r'reading_frame=1.*start=\'require\''):
             self.sgc.translate(seq, start='require')
 
         # non-start codon that translates to an AA that start codons also map
@@ -306,7 +306,7 @@ class TestGeneticCode(unittest.TestCase):
             self.assertEqual(obs, exp)
 
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=1.*start=\'require\''):
+                                    r'reading_frame=1.*start=\'require\''):
             self.sgc.translate(seq, start='require')
 
     def test_translate_start_no_accidental_mutation(self):
@@ -331,7 +331,7 @@ class TestGeneticCode(unittest.TestCase):
                 self.assertEqual(obs, exp)
 
             with self.assertRaisesRegex(ValueError,
-                                        'reading_frame=1.*stop=\'require\''):
+                                        r'reading_frame=1.*stop=\'require\''):
                 self.sgc.translate(seq, stop='require')
 
     def test_translate_stop_with_stop_codon(self):
@@ -377,7 +377,7 @@ class TestGeneticCode(unittest.TestCase):
             self.assertEqual(obs, exp)
 
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=1.*stop=\'require\''):
+                                    r'reading_frame=1.*stop=\'require\''):
             self.sgc.translate(seq, stop='require')
 
     def test_translate_trim_to_cds(self):
@@ -399,10 +399,10 @@ class TestGeneticCode(unittest.TestCase):
         #     AAUUGCCUCAUUAAUAACAAUGA
         #     NCLINNN
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=2.*start=\'require\''):
+                                    r'reading_frame=2.*start=\'require\''):
             self.sgc.translate(seq, reading_frame=2, start='require')
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=2.*stop=\'require\''):
+                                    r'reading_frame=2.*stop=\'require\''):
             self.sgc.translate(seq, reading_frame=2, stop='require')
 
         exp = Protein('NCLINNN')
@@ -413,29 +413,29 @@ class TestGeneticCode(unittest.TestCase):
 
     def test_translate_invalid_input(self):
         # invalid sequence type
-        with self.assertRaisesRegex(TypeError, 'RNA.*DNA'):
+        with self.assertRaisesRegex(TypeError, r'RNA.*DNA'):
             self.sgc.translate(DNA('ACG'))
-        with self.assertRaisesRegex(TypeError, 'RNA.*str'):
+        with self.assertRaisesRegex(TypeError, r'RNA.*str'):
             self.sgc.translate('ACG')
 
         # invalid reading frame
-        with self.assertRaisesRegex(ValueError, '\[1, 2, 3, -1, -2, -3\].*0'):
+        with self.assertRaisesRegex(ValueError, r'\[1, 2, 3, -1, -2, -3\].*0'):
             self.sgc.translate(RNA('AUG'), reading_frame=0)
 
         # invalid start
-        with self.assertRaisesRegex(ValueError, 'start.*foo'):
+        with self.assertRaisesRegex(ValueError, r'start.*foo'):
             self.sgc.translate(RNA('AUG'), start='foo')
 
         # invalid stop
-        with self.assertRaisesRegex(ValueError, 'stop.*foo'):
+        with self.assertRaisesRegex(ValueError, r'stop.*foo'):
             self.sgc.translate(RNA('AUG'), stop='foo')
 
         # gapped sequence
-        with self.assertRaisesRegex(ValueError, 'gapped'):
+        with self.assertRaisesRegex(ValueError, r'gapped'):
             self.sgc.translate(RNA('UU-G'))
 
         # degenerate sequence
-        with self.assertRaisesRegex(NotImplementedError, 'degenerate'):
+        with self.assertRaisesRegex(NotImplementedError, r'degenerate'):
             self.sgc.translate(RNA('RUG'))
 
     def test_translate_varied_genetic_codes(self):
@@ -458,7 +458,7 @@ class TestGeneticCode(unittest.TestCase):
         self.assertEqual(obs, exp)
 
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=1.*start=\'require\''):
+                                    r'reading_frame=1.*start=\'require\''):
             GeneticCode.from_ncbi(22).translate(seq, start='require',
                                                 stop='require')
 
@@ -469,7 +469,7 @@ class TestGeneticCode(unittest.TestCase):
         self.assertEqual(obs, exp)
 
         with self.assertRaisesRegex(ValueError,
-                                    'reading_frame=1.*start=\'require\''):
+                                    r'reading_frame=1.*start=\'require\''):
             gc.translate(seq, start='require', stop='require')
 
     def test_translate_six_frames(self):
