@@ -50,7 +50,7 @@ class TestGrammaredSequence(TestCase):
     def test_default_gap_must_be_in_gap_chars(self):
         with self.assertRaisesRegex(
                 TypeError,
-                "default_gap_char must be in gap_chars for class "
+                r"default_gap_char must be in gap_chars for class "
                 "GrammaredSequenceInvalidDefaultGap"):
 
             class GrammaredSequenceInvalidDefaultGap(ExampleGrammaredSequence):
@@ -61,7 +61,7 @@ class TestGrammaredSequence(TestCase):
     def test_degenerates_must_expand_to_valid_definites(self):
         with self.assertRaisesRegex(
                 TypeError,
-                "degenerate_map must expand only to characters included in "
+                r"degenerate_map must expand only to characters included in "
                 "definite_chars for class "
                 "GrammaredSequenceInvalidDefaultGap"):
 
@@ -77,8 +77,8 @@ class TestGrammaredSequence(TestCase):
     def test_gap_chars_and_degenerates_share(self):
         with self.assertRaisesRegex(
                 TypeError,
-                "gap_chars and degenerate_chars must not share any characters "
-                "for class GrammaredSequenceGapInDegenerateMap"):
+                r"gap_chars and degenerate_chars must not share any characters"
+                " for class GrammaredSequenceGapInDegenerateMap"):
 
             class GrammaredSequenceGapInDegenerateMap(
                     ExampleGrammaredSequence):
@@ -97,7 +97,7 @@ class TestGrammaredSequence(TestCase):
     def test_gap_chars_and_definites_share(self):
         with self.assertRaisesRegex(
             TypeError,
-            ("gap_chars and definite_chars must not share any characters "
+            (r"gap_chars and definite_chars must not share any characters "
              "for class GrammaredSequenceGapInDefiniteMap")):
 
             class GrammaredSequenceGapInDefiniteMap(
@@ -117,7 +117,7 @@ class TestGrammaredSequence(TestCase):
     def test_degenerates_and_definites_share(self):
         with self.assertRaisesRegex(
             TypeError,
-            ("degenerate_chars and definite_chars must not share any "
+            (r"degenerate_chars and definite_chars must not share any "
              "characters for class GrammaredSequenceInvalid")):
 
             class GrammaredSequenceInvalid(ExampleGrammaredSequence):
@@ -192,7 +192,7 @@ class TestGrammaredSequence(TestCase):
     def test_init_validate_parameter_single_character(self):
         seq = 'w'
 
-        with self.assertRaisesRegex(ValueError, "character.*'w'"):
+        with self.assertRaisesRegex(ValueError, r"character.*'w'"):
             ExampleGrammaredSequence(seq)
 
         # test that we can instantiate an invalid sequence. we don't guarantee
@@ -204,7 +204,7 @@ class TestGrammaredSequence(TestCase):
         # alphabet characters
         seq = 'CBCBBbawCbbwBXYZ-.x'
 
-        with self.assertRaisesRegex(ValueError, "\['a', 'b', 'w', 'x'\]"):
+        with self.assertRaisesRegex(ValueError, r"\['a', 'b', 'w', 'x'\]"):
             ExampleGrammaredSequence(seq)
 
         ExampleGrammaredSequence(seq, validate=False)
@@ -213,7 +213,7 @@ class TestGrammaredSequence(TestCase):
         s = 'cbcbbbazcbbzbxyz-.x'
 
         with self.assertRaisesRegex(ValueError,
-                                    "\['a', 'b', 'c', 'x', 'y', 'z'\]"):
+                                    r"\['a', 'b', 'c', 'x', 'y', 'z'\]"):
             ExampleGrammaredSequence(s)
 
         seq = ExampleGrammaredSequence(s, lowercase=True)
@@ -222,7 +222,7 @@ class TestGrammaredSequence(TestCase):
     def test_init_lowercase_mixed_case(self):
         s = 'CBCBBbazCbbzBXYZ-.x'
 
-        with self.assertRaisesRegex(ValueError, "\['a', 'b', 'x', 'z'\]"):
+        with self.assertRaisesRegex(ValueError, r"\['a', 'b', 'x', 'z'\]"):
             ExampleGrammaredSequence(s)
 
         seq = ExampleGrammaredSequence(s, lowercase=True)
@@ -231,10 +231,10 @@ class TestGrammaredSequence(TestCase):
     def test_init_lowercase_no_validation(self):
         s = 'car'
 
-        with self.assertRaisesRegex(ValueError, "\['a', 'c', 'r'\]"):
+        with self.assertRaisesRegex(ValueError, r"\['a', 'c', 'r'\]"):
             ExampleGrammaredSequence(s)
 
-        with self.assertRaisesRegex(ValueError, "character.*'R'"):
+        with self.assertRaisesRegex(ValueError, r"character.*'R'"):
             ExampleGrammaredSequence(s, lowercase=True)
 
         ExampleGrammaredSequence(s, lowercase=True, validate=False)
@@ -242,7 +242,7 @@ class TestGrammaredSequence(TestCase):
     def test_init_lowercase_byte_ownership(self):
         bytes = np.array([97, 98, 97], dtype=np.uint8)
 
-        with self.assertRaisesRegex(ValueError, "\['a', 'b'\]"):
+        with self.assertRaisesRegex(ValueError, r"\['a', 'b'\]"):
             ExampleGrammaredSequence(bytes)
 
         seq = ExampleGrammaredSequence(bytes, lowercase=True)
@@ -259,7 +259,7 @@ class TestGrammaredSequence(TestCase):
         for invalid_key in ((), [], 2):
             invalid_type = type(invalid_key)
             with self.assertRaisesRegex(TypeError,
-                                        "lowercase keyword argument expected "
+                                        r"lowercase keyword argument expected "
                                         "a bool or string, but got %s" %
                                         invalid_type):
                 ExampleGrammaredSequence('ACGTacgt', lowercase=invalid_key)
