@@ -125,7 +125,7 @@ class TestProtein(unittest.TestCase):
         self.assertIn('has stops: True', obs)
 
     def test_cannot_subclass(self):
-        with self.assertRaisesRegex(TypeError, "Subclassing disabled"):
+        with self.assertRaisesRegex(TypeError, r"Subclassing disabled"):
             class CustomSequence(Protein):
                 pass
 
